@@ -1,3 +1,15 @@
+# jdebug.tcl - optional debugging log (not very useful)
+#
+######################################################################
+# Copyright 1992-1995 by Jay Sekora.  This file may be freely        #
+# distributed, modified or unmodified, for any purpose, provided     #
+# that this copyright notice is retained verbatim in all copies and  #
+# no attempt is made to obscure the authorship of this file.  If you #
+# distribute any modified versions, I ask, but do not require, that  #
+# you clearly mark any changes you make as such and that you provide #
+# your users with instructions for getting the original sources.     #
+######################################################################
+
 ######################################################################
 # record debugging information
 ######################################################################
@@ -14,7 +26,7 @@ proc j:debug { {string {j:debug called}} } {
     toplevel $w
     wm minsize . 10 10
     text $w.t -yscrollcommand "$w.sb set" -setgrid true
-    scrollbar $w.sb -relief flat -command "$w.t yview"
+    scrollbar $w.sb -command "$w.t yview"
     pack $w.sb $w.t -side $J_PREFS(scrollbarside) -fill y
   }
   
@@ -37,3 +49,4 @@ proc j:debug { {string {j:debug called}} } {
 } else {
   proc j:debug args {}
 }
+
