@@ -16,6 +16,10 @@ proc mode:note:init { t } {
     {autoindent 1}
     {savestate 1}
     {buttonbar 1}
+    {buttons {
+      jedit:cmd:done
+      jedit:cmd:quit
+    }}
     {menu,editor 1}
     {menu,file 1}
     {menu,edit 1}
@@ -29,14 +33,3 @@ proc mode:note:init { t } {
     {menu,user 1}
   }
 }
-
-######################################################################
-# define the button bar:
-
-proc mode:note:mkbuttons { w t } {
-  j:buttonbar $w -pady 2 -buttons [format {
-    {done Done {jedit:cmd:done %s}}
-    {quit Quit {jedit:cmd:quit %s}}
-  } $t $t]
-  return $w
-}
