@@ -2,6 +2,9 @@ abbrev 0 0
 abbrev 10q {thank you}
 abbrev 2b {to be}
 abbrev 2ni tonight
+abbrev DNl4 {The Netherlands}
+abbrev Dnl4 {The Netherlands}
+abbrev SFr {San Francisco}
 abbrev ZA4 {South Africa}
 abbrev a1 anyone
 abbrev ab about
@@ -23,12 +26,14 @@ abbrev addy additionally
 abbrev adv advance
 abbrev advs advances
 abbrev af after
+abbrev afaik {as far as I know}
 abbrev afn afternoon
 abbrev afr afraid
 abbrev afw afterwards
 abbrev ag again
 abbrev agst against
 abbrev ahd ahead
+abbrev ak4 alaska
 abbrev aka a/k/a
 abbrev al along
 abbrev alm almost
@@ -200,8 +205,10 @@ abbrev cyg copying
 abbrev cying copying
 abbrev cys copies
 abbrev d the
+abbrev dNl4 {the Netherlands}
 abbrev dau daughter
 abbrev daus daughters
+abbrev ddn didn't
 abbrev de there
 abbrev de4 delaware
 abbrev dec4 december
@@ -209,6 +216,7 @@ abbrev defn definition
 abbrev defns definitions
 abbrev deir their
 abbrev deirf theirselves
+abbrev deirs theirs
 abbrev del delete
 abbrev dels deletes
 abbrev dem them
@@ -221,6 +229,8 @@ abbrev deptl departmental
 abbrev depts departments
 abbrev des these
 abbrev dese these
+abbrev devt development
+abbrev devts developments
 abbrev dey they
 abbrev deyr they're
 abbrev deyv they've
@@ -237,8 +247,10 @@ abbrev dis this
 abbrev distn distribution
 abbrev distns distributions
 abbrev dm them
+abbrev dmf themselves
 abbrev dn doesn't
 abbrev dne {david and ellen}
+abbrev dnl4 {the netherlands}
 abbrev dnti downtime
 abbrev doc document
 abbrev docn documentation
@@ -362,7 +374,9 @@ abbrev gter greater
 abbrev gtr greater
 abbrev h have
 abbrev h2 {have to}
+abbrev h2b {have to be}
 abbrev havg having
+abbrev hd heidi
 abbrev herf herself
 abbrev hev however
 abbrev hf himself
@@ -510,6 +524,7 @@ abbrev nis night
 abbrev nite night
 abbrev nites night
 abbrev nj4 {new jersey}
+abbrev nl4 netherlands
 abbrev nm4 {new mexico}
 abbrev nnj {neils and julianne}
 abbrev noho northampton
@@ -653,6 +668,7 @@ abbrev qx x
 abbrev qy y
 abbrev qz z
 abbrev r are
+abbrev ra rhonda
 abbrev rad rather
 abbrev reln relation
 abbrev relns relations
@@ -727,6 +743,7 @@ abbrev sev several
 abbrev sevl several
 abbrev sevlly severally
 abbrev sevly severally
+abbrev sfr {san francisco}
 abbrev sh somehow
 abbrev shd should
 abbrev sim similar
@@ -755,6 +772,8 @@ abbrev str straight
 abbrev str8fw straightforward
 abbrev str8fwly straightforwardly
 abbrev str8s straight
+abbrev strfw straightforward
+abbrev strfwly straightforwardly
 abbrev strs straights
 abbrev su4 sunday
 abbrev subdir subdirectory
@@ -909,6 +928,7 @@ abbrev xsectn intersection
 abbrev xsectns intersections
 abbrev xsects intersects
 abbrev xw {X Windows}
+abbrev xy christy
 abbrev y you
 abbrev yd you'd
 abbrev ydy yesterday
